<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>InfoDistanceEP</name>
    <message>
        <location filename="../InfoDistanceEP.js" line="+59"/>
        <source>Specify entity</source>
        <translation>Určete objekt</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Specify point</source>
        <translation>Určete bod</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Done</source>
        <translation>Dokončeno</translation>
    </message>
    <message>
        <location line="+79"/>
        <source>Distance:</source>
        <translation>Vzdálenost:</translation>
    </message>
    <message>
        <location filename="../InfoDistanceEPInit.js" line="+2"/>
        <source>Distance &amp;Entity to Point</source>
        <translation>Vzdálenost mezi &amp;objektem a bodem</translation>
    </message>
</context>
</TS>
